==> civicrm_4.7.30+dfsg.orig.tar.xz: civicrm/release-notes.md <==
# Release Notes

These release notes are manually compiled from pull requests and Jira issues
starting with CiviCRM 4.7.14.

Other resources for identifying changes are:

* The Jira project management system at https://issues.civicrm.org
* The following GitHub projects:
    * https://github.com/civicrm/civicrm-core
    * https://github.com/civicrm/civicrm-packages
    * https://github.com/civicrm/civicrm-backdrop
    * https://github.com/civicrm/civicrm-drupal
    * https://github.com/civicrm/civicrm-joomla
    * https://github.com/civicrm/civicrm-wordpress

## CiviCRM 4.7.30

Released February 7, 2018

- **[Synopsis](release-notes/4.7.30.md#synopsis)**
- **[Features](release-notes/4.7.30.md#features)**
- **[Bugs resolved](release-notes/4.7.30.md#bugs)**
- **[Miscellany](release-notes/4.7.30.md#misc)**
- **[Credits](release-notes/4.7.30.md#credits)**
- **[Feedback](release-notes/4.7.30.md#feedback)**

## CiviCRM 4.7.29

Released December 20, 2017

- **[Synopsis](release-notes/4.7.29.md#synopsis)**
- **[Features](release-notes/4.7.29.md#features)**
- **[Bugs resolved](release-notes/4.7.29.md#bugs)**
- **[Credits](release-notes/4.7.29.md#credits)**
- **[Feedback](release-notes/4.7.29.md#feedback)**

## CiviCRM 4.7.28

Released December 6, 2017

- **[Synopsis](release-notes/4.7.28.md#synopsis)**
- **[Features](release-notes/4.7.28.md#features)**
- **[Bugs resolved](release-notes/4.7.28.md#bugs)**
- **[Miscellany](release-notes/4.7.28.md#misc)**
- **[Credits](release-notes/4.7.28.md#credits)**
- **[Feedback](release-notes/4.7.28.md#feedback)**

## CiviCRM 4.7.27

Released November 1, 2017

- **[Synopsis](release-notes/4.7.27.md#synopsis)**
- **[Features](release-notes/4.7.27.md#features)**
- **[Bugs resolved](release-notes/4.7.27.md#bugs)**
- **[Miscellany](release-notes/4.7.27.md#misc)**
- **[Credits](release-notes/4.7.27.md#credits)**
- **[Feedback](release-notes/4.7.27.md#feedback)**

## CiviCRM 4.7.26

Released November 1, 2017

- **[Security](release-notes/4.7.26.md#security)**
- **[Credits](release-notes/4.7.26.md#credits)**

## CiviCRM 4.7.25

Released October 4, 2017

- **[Synopsis](release-notes/4.7.25.md#synopsis)**
- **[Features](release-notes/4.7.25.md#features)**
- **[Bugs resolved](release-notes/4.7.25.md#bugs)**
- **[Miscellany](release-notes/4.7.25.md#misc)**
- **[Credits](release-notes/4.7.25.md#credits)**
- **[Feedback](release-notes/4.7.25.md#feedback)**

## CiviCRM 4.7.24

Released September 6, 2017

- **[Synopsis](release-notes/4.7.24.md#synopsis)**
- **[Features](release-notes/4.7.24.md#features)**
- **[Bugs resolved](release-notes/4.7.24.md#bugs)**
- **[Miscellany](release-notes/4.7.24.md#misc)**
- **[Credits](release-notes/4.7.24.md#credits)**
- **[Feedback](release-notes/4.7.24.md#feedback)**

## CiviCRM 4.7.23

Released August 2, 2017

- **[Synopsis](release-notes/4.7.23.md#synopsis)**
- **[Features](release-notes/4.7.23.md#features)**
- **[Bugs resolved](release-notes/4.7.23.md#bugs)**
- **[Miscellany](release-notes/4.7.23.md#misc)**
- **[Credits](release-notes/4.7.23.md#credits)**
- **[Feedback](release-notes/4.7.23.md#feedback)**

## CiviCRM 4.7.22

Released July 12, 2017

- **[Bugs resolved](release-notes/4.7.22.md#bugs)**
- **[Credits](release-notes/4.7.22.md#credits)**

## CiviCRM 4.7.21

Released July 5, 2017

- **[Features](release-notes/4.7.21.md#features)**
- **[Bugs resolved](release-notes/4.7.21.md#bugs)**
- **[Miscellany](release-notes/4.7.21.md#misc)**
- **[Credits](release-notes/4.7.21.md#credits)**

## CiviCRM 4.7.20

Released June 7, 2017

- **[Features](release-notes/4.7.20.md#features)**
- **[Bugs resolved](release-notes/4.7.20.md#bugs)**
- **[Miscellany](release-notes/4.7.20.md#misc)**
- **[Credits](release-notes/4.7.20.md#credits)**

## CiviCRM 4.7.19

Released May 3, 2017

- **[Features](release-notes/4.7.19.md#features)**
- **[Bugs resolved](release-notes/4.7.19.md#bugs)**
- **[Miscellany](release-notes/4.7.19.md#misc)**
- **[Credits](release-notes/4.7.19.md#credits)**

## CiviCRM 4.7.18

Released April 5, 2017

- **[Features](release-notes/4.7.18.md#features)**
- **[Bugs resolved](release-notes/4.7.18.md#bugs)**
- **[Miscellany](release-notes/4.7.18.md#misc)**
- **[Credits](release-notes/4.7.18.md#credits)**

## CiviCRM 4.7.17

Released March 8, 2017

- **[Features](release-notes/4.7.17.md#features)**
- **[Bugs resolved](release-notes/4.7.17.md#bugs)**
- **[Miscellany](release-notes/4.7.17.md#misc)**
- **[Credits](release-notes/4.7.17.md#credits)**

## CiviCRM 4.7.16

Released February 8, 2017

- **[Features](release-notes/4.7.16.md#features)**
- **[Bugs resolved](release-notes/4.7.16.md#bugs)**
- **[Miscellany](release-notes/4.7.16.md#misc)**
- **[Credits](release-notes/4.7.16.md#credits)**

## CiviCRM 4.7.15

Released January 4, 2017

- **[Features](release-notes/4.7.15.md#features)**
- **[Bugs resolved](release-notes/4.7.15.md#bugs)**
- **[Credits](release-notes/4.7.15.md#credits)**

## CiviCRM 4.7.14

Released December 7, 2016

- **[Features](release-notes/4.7.14.md#features)**
- **[Bugs resolved](release-notes/4.7.14.md#bugs)**
- **[Credits](release-notes/4.7.14.md#credits)**

==> civicrm_5.3.1+dfsg.orig.tar.xz: civicrm/release-notes.md <==
# Release Notes

These release notes are manually compiled from pull requests and Jira issues
starting with CiviCRM 4.7.14.

Other resources for identifying changes are:

* The Jira project management system at https://issues.civicrm.org
* The following GitHub projects:
    * https://github.com/civicrm/civicrm-core
    * https://github.com/civicrm/civicrm-packages
    * https://github.com/civicrm/civicrm-backdrop
    * https://github.com/civicrm/civicrm-drupal
    * https://github.com/civicrm/civicrm-joomla
    * https://github.com/civicrm/civicrm-wordpress

## CiviCRM 5.3.0

Released July 3, 2018

- **[Synopsis](release-notes/5.3.0.md#synopsis)**
- **[Features](release-notes/5.3.0.md#features)**
- **[Bugs resolved](release-notes/5.3.0.md#bugs)**
- **[Miscellany](release-notes/5.3.0.md#misc)**
- **[Credits](release-notes/5.3.0.md#credits)**
- **[Feedback](release-notes/5.3.0.md#feedback)**

## CiviCRM 5.2.2

Released June 19, 2018

- **[Synopsis](release-notes/5.2.2.md#synopsis)**
- **[Bugs resolved](release-notes/5.2.2.md#bugs)**
- **[Credits](release-notes/5.2.2.md#credits)**
- **[Feedback](release-notes/5.2.2.md#feedback)**

## CiviCRM 5.2.1

Released June 8, 2018

- **[Synopsis](release-notes/5.2.1.md#synopsis)**
- **[Bugs resolved](release-notes/5.2.1.md#bugs)**
- **[Credits](release-notes/5.2.1.md#credits)**
- **[Feedback](release-notes/5.2.1.md#feedback)**

## CiviCRM 5.2.0

Released June 6, 2018

- **[Synopsis](release-notes/5.2.0.md#synopsis)**
- **[Features](release-notes/5.2.0.md#features)**
- **[Bugs resolved](release-notes/5.2.0.md#bugs)**
- **[Miscellany](release-notes/5.2.0.md#misc)**
- **[Credits](release-notes/5.2.0.md#credits)**
- **[Feedback](release-notes/5.2.0.md#feedback)**

## CiviCRM 5.1.2

Released May 16, 2018

- **[Synopsis](release-notes/5.1.2.md#synopsis)**
- **[Bugs resolved](release-notes/5.1.2.md#bugs)**
- **[Credits](release-notes/5.1.2.md#credits)**
- **[Feedback](release-notes/5.1.2.md#feedback)**

## CiviCRM 5.1.1

Released May 15, 2018

- **[Synopsis](release-notes/5.1.1.md#synopsis)**
- **[Features](release-notes/5.1.1.md#features)**
- **[Bugs resolved](release-notes/5.1.1.md#bugs)**
- **[Credits](release-notes/5.1.1.md#credits)**
- **[Feedback](release-notes/5.1.1.md#feedback)**

## CiviCRM 5.1.0

Released May 2, 2018

- **[Synopsis](release-notes/5.1.0.md#synopsis)**
- **[Features](release-notes/5.1.0.md#features)**
- **[Bugs resolved](release-notes/5.1.0.md#bugs)**
- **[Miscellany](release-notes/5.1.0.md#misc)**
- **[Credits](release-notes/5.1.0.md#credits)**
- **[Feedback](release-notes/5.1.0.md#feedback)**

## CiviCRM 5.0.2

Released Apr 25, 2018

- **[Synopsis](release-notes/5.0.2.md#synopsis)**
- **[Bugs resolved](release-notes/5.0.2.md#bugs)**
- **[Credits](release-notes/5.0.2.md#credits)**
- **[Feedback](release-notes/5.0.2.md#feedback)**

## CiviCRM 5.0.1

Released April 19, 2018

- **[Synopsis](release-notes/5.0.1.md#synopsis)**
- **[Features](release-notes/5.0.1.md#features)**
- **[Bugs resolved](release-notes/5.0.1.md#bugs)**
- **[Credits](release-notes/5.0.1.md#credits)**
- **[Feedback](release-notes/5.0.1.md#feedback)**

## CiviCRM 5.0.0

Released April 4, 2018

- **[Synopsis](release-notes/5.0.0.md#synopsis)**
- **[Features](release-notes/5.0.0.md#features)**
- **[Bugs resolved](release-notes/5.0.0.md#bugs)**
- **[Miscellany](release-notes/5.0.0.md#misc)**
- **[Credits](release-notes/5.0.0.md#credits)**
- **[Feedback](release-notes/5.0.0.md#feedback)**

## CiviCRM 4.7.31

Released March 7, 2018

- **[Synopsis](release-notes/4.7.31.md#synopsis)**
- **[Features](release-notes/4.7.31.md#features)**
- **[Bugs resolved](release-notes/4.7.31.md#bugs)**
- **[Miscellany](release-notes/4.7.31.md#misc)**
- **[Credits](release-notes/4.7.31.md#credits)**
- **[Feedback](release-notes/4.7.31.md#feedback)**

## CiviCRM 4.7.30

Released February 7, 2018

- **[Synopsis](release-notes/4.7.30.md#synopsis)**
- **[Features](release-notes/4.7.30.md#features)**
- **[Bugs resolved](release-notes/4.7.30.md#bugs)**
- **[Miscellany](release-notes/4.7.30.md#misc)**
- **[Credits](release-notes/4.7.30.md#credits)**
- **[Feedback](release-notes/4.7.30.md#feedback)**

## CiviCRM 4.7.29

Released December 20, 2017

- **[Synopsis](release-notes/4.7.29.md#synopsis)**
- **[Features](release-notes/4.7.29.md#features)**
- **[Bugs resolved](release-notes/4.7.29.md#bugs)**
- **[Credits](release-notes/4.7.29.md#credits)**
- **[Feedback](release-notes/4.7.29.md#feedback)**

## CiviCRM 4.7.28

Released December 6, 2017

- **[Synopsis](release-notes/4.7.28.md#synopsis)**
- **[Features](release-notes/4.7.28.md#features)**
- **[Bugs resolved](release-notes/4.7.28.md#bugs)**
- **[Miscellany](release-notes/4.7.28.md#misc)**
- **[Credits](release-notes/4.7.28.md#credits)**
- **[Feedback](release-notes/4.7.28.md#feedback)**

## CiviCRM 4.7.27

Released November 1, 2017

- **[Synopsis](release-notes/4.7.27.md#synopsis)**
- **[Features](release-notes/4.7.27.md#features)**
- **[Bugs resolved](release-notes/4.7.27.md#bugs)**
- **[Miscellany](release-notes/4.7.27.md#misc)**
- **[Credits](release-notes/4.7.27.md#credits)**
- **[Feedback](release-notes/4.7.27.md#feedback)**

## CiviCRM 4.7.26

Released November 1, 2017

- **[Security](release-notes/4.7.26.md#security)**
- **[Credits](release-notes/4.7.26.md#credits)**

## CiviCRM 4.7.25

Released October 4, 2017

- **[Synopsis](release-notes/4.7.25.md#synopsis)**
- **[Features](release-notes/4.7.25.md#features)**
- **[Bugs resolved](release-notes/4.7.25.md#bugs)**
- **[Miscellany](release-notes/4.7.25.md#misc)**
- **[Credits](release-notes/4.7.25.md#credits)**
- **[Feedback](release-notes/4.7.25.md#feedback)**

## CiviCRM 4.7.24

Released September 6, 2017

- **[Synopsis](release-notes/4.7.24.md#synopsis)**
- **[Features](release-notes/4.7.24.md#features)**
- **[Bugs resolved](release-notes/4.7.24.md#bugs)**
- **[Miscellany](release-notes/4.7.24.md#misc)**
- **[Credits](release-notes/4.7.24.md#credits)**
- **[Feedback](release-notes/4.7.24.md#feedback)**

## CiviCRM 4.7.23

Released August 2, 2017

- **[Synopsis](release-notes/4.7.23.md#synopsis)**
- **[Features](release-notes/4.7.23.md#features)**
- **[Bugs resolved](release-notes/4.7.23.md#bugs)**
- **[Miscellany](release-notes/4.7.23.md#misc)**
- **[Credits](release-notes/4.7.23.md#credits)**
- **[Feedback](release-notes/4.7.23.md#feedback)**

## CiviCRM 4.7.22

Released July 12, 2017

- **[Bugs resolved](release-notes/4.7.22.md#bugs)**
- **[Credits](release-notes/4.7.22.md#credits)**

## CiviCRM 4.7.21

Released July 5, 2017

- **[Features](release-notes/4.7.21.md#features)**
- **[Bugs resolved](release-notes/4.7.21.md#bugs)**
- **[Miscellany](release-notes/4.7.21.md#misc)**
- **[Credits](release-notes/4.7.21.md#credits)**

## CiviCRM 4.7.20

Released June 7, 2017

- **[Features](release-notes/4.7.20.md#features)**
- **[Bugs resolved](release-notes/4.7.20.md#bugs)**
- **[Miscellany](release-notes/4.7.20.md#misc)**
- **[Credits](release-notes/4.7.20.md#credits)**

## CiviCRM 4.7.19

Released May 3, 2017

- **[Features](release-notes/4.7.19.md#features)**
- **[Bugs resolved](release-notes/4.7.19.md#bugs)**
- **[Miscellany](release-notes/4.7.19.md#misc)**
- **[Credits](release-notes/4.7.19.md#credits)**

## CiviCRM 4.7.18

Released April 5, 2017

- **[Features](release-notes/4.7.18.md#features)**
- **[Bugs resolved](release-notes/4.7.18.md#bugs)**
- **[Miscellany](release-notes/4.7.18.md#misc)**
- **[Credits](release-notes/4.7.18.md#credits)**

## CiviCRM 4.7.17

Released March 8, 2017

- **[Features](release-notes/4.7.17.md#features)**
- **[Bugs resolved](release-notes/4.7.17.md#bugs)**
- **[Miscellany](release-notes/4.7.17.md#misc)**
- **[Credits](release-notes/4.7.17.md#credits)**

## CiviCRM 4.7.16

Released February 8, 2017

- **[Features](release-notes/4.7.16.md#features)**
- **[Bugs resolved](release-notes/4.7.16.md#bugs)**
- **[Miscellany](release-notes/4.7.16.md#misc)**
- **[Credits](release-notes/4.7.16.md#credits)**

## CiviCRM 4.7.15

Released January 4, 2017

- **[Features](release-notes/4.7.15.md#features)**
- **[Bugs resolved](release-notes/4.7.15.md#bugs)**
- **[Credits](release-notes/4.7.15.md#credits)**

## CiviCRM 4.7.14

Released December 7, 2016

- **[Features](release-notes/4.7.14.md#features)**
- **[Bugs resolved](release-notes/4.7.14.md#bugs)**
- **[Credits](release-notes/4.7.14.md#credits)**
